@@ -408,9 +408,9 @@ class PotholeSegmentationUseCase(BaseProcessor):
             stream_info: Optional[Dict[str, Any]] = None
     ) -> List[Dict]:
         """Generate structured tracking stats for the output format with frame-based keys, including track_ids_info and detections with masks."""
-        frame_key = str(frame_number) if frame_number is not None else "current_frame"
-        tracking_stats = [{frame_key: []}]
-        frame_tracking_stats = tracking_stats[0][frame_key]
+        #frame_key = str(frame_number) if frame_number is not None else "current_frame"
+        tracking_stats = [] #[{frame_key: []}]
+        #frame_tracking_stats = tracking_stats[0][frame_key]
 
         total_detections = counting_summary.get("total_count", 0)
         total_counts = counting_summary.get("total_counts", {})
