@@ -57,7 +57,7 @@ class WeaponDetectionUseCase(BaseProcessor):
 
     def __init__(self):
         super().__init__("weapon_detection")
-        self.category = "weapon_detection"
+        self.category = "security"
         self.CASE_TYPE: Optional[str] = 'weapon_detection'
         self.CASE_VERSION: Optional[str] = '1.0'
         self.target_categories = ['bluntweapon', 'glass', 'gun', 'knife', 'monedero', 'pistol', 'tarjeta']
